@@ -26,12 +26,14 @@
 #
 #####
 package Net::Telnet::Cisco::IOS;
-use Net::Telnet::Cisco;
 
+use Net::Telnet::Cisco;
+use strict;
+use vars qw($AUTOLOAD @ISA $VERSION $DEBUG);
 #  Declare ourselves a child of Net::Telnet::Cisco
 @ISA        = qw(Net::Telnet::Cisco);
 #  Keep the version number
-$VERSION    = "0.4beta";
+$VERSION    = "0.5beta";
 
 #  Constructor
 sub new  {
@@ -59,16 +61,14 @@ sub getModVer  {
 }
 
 #  Returns IOS version of router
+#  Priv 1
 sub getIOSVer  {
 	my $cmd = "show version";
 	my $self = shift;
 	#  Try to run the command
-        if ( ! (@result = $self->cmd( $cmd ) ) )  {
-                #  If it failed, return 0
-                return 0;
-        }
+        my @result = $self->cmd( $cmd );
 
-	foreach $line ( @result )  {
+	foreach my $line ( @result )  {
 		if ( $line =~ /, Version (.+),/ )  {
 			return $1;
 		}
@@ -78,72 +78,63 @@ sub getIOSVer  {
 
 
 #  Returns hash of 5-sec, 1-min, and 5-minute CPU averages
+#  Priv 1
 sub getCPU  {
         #  cmd is what command we send to the IOS device
         my $cmd = "show process cpu";
 	#  Initialize the hash
-	my %result = ();
+	my %ret = (  	"5sec" => "na",
+			"1min" => "na",
+			"5min" => "na"
+			);
         #  Set the object up
         my $self = shift;
         #  Try to run the command
-        if ( ! (@result = $self->cmd( $cmd ) ) )  {
-                #  If it failed, return 0
-                return 0;
-        }
-	foreach $line ( @result )  {
+        my @result = $self->cmd( $cmd );
+
+	foreach my $line ( @result )  {
 		if ( $line =~ /five seconds: (.+)\/.+; one minute: (.+); five minutes: (.+)/ )  {
-			$result{ "5sec" } = $1;
-			$result{ "1min" } = $2;
-			$result{ "5min" } = $3;
-			return %result;
+			$ret{ "5sec" } = $1;
+			$ret{ "1min" } = $2;
+			$ret{ "5min" } = $3;
 		}
 	}
-	return 0;
+	return %ret;
 }
 		
 #  Returns all the ints in an array
+#  Priv 1
 sub listInts  {
 	my $self = shift;
 	my @ret;
 	my $int;
 	my $cmd = "sh ip interface brief";
-	
-	if ( ! ( @result = $self->cmd( $cmd ) ) )  {
-		return 0;
-	}
+	my @result = $self->cmd( $cmd );
 
-	foreach $line ( @result )  {
-		chomp( $line );
+	foreach my $line ( @result )  {
 		if ( $line =~ /^Interface/i )  { }
 		elsif ( $line =~ /^-----/ )  { }
 		elsif ( $line =~ /^\s/ )  { }
 		elsif ( $line =~ /^\W/ )  { }
 		else  {
-			$int = substr( $line, 0, 23 );
-			if ( length ( $int ) == 0 )  { }
-			else  {
-				$int =~ s/\s+$//g;
-				push ( @ret, $int );
-			}
-			push ( @rest, $1 );
+			my $int = substr( $line, 0, 23 );
+			$int =~ s/\s+$//g;
+			push ( @ret, $int );
 		}
 	}
 	return @ret;
 }
 
+#  Priv 1
 sub listVLANs  {
 	my $self = shift;
 	my @ret;
 	my $cmd = "show vlan brief";
 	my ( $vlanid, $vlanname );
-        #  Try to run the command
-        if ( ! ( @result = $self->cmd( $cmd ) ) )  {
-                #  If it failed, return 0
-                return 0;
-        }
+        my @result = $self->cmd( $cmd );
 
 	#  Go through each line of the command result
-        foreach $line ( @result )  {
+        foreach my $line ( @result )  {
                 #  If it starts with "Port", do nothing
                 if ( $line =~ /^VLAN/i )  { }
                 #  If it starts with "----", do nothing
@@ -166,15 +157,15 @@ sub listVLANs  {
         return @ret;
 }	
 
+#  Priv 1
 sub getIntState  {
         my ( $self, @args ) = @_;
 	my %result;
-        $if = &harmonizeInts( $args[0] );
-        $cmd = "sh interface " . $if;
-        if ( !( @output = $self->cmd( $cmd ) ) ) {
-                return 0;
-        }
-        foreach $line ( @output )  {
+        my $if = &harmonizeInts( $args[0] );
+        my $cmd = "sh interface " . $if;
+        my @output = $self->cmd( $cmd );
+
+        foreach my $line ( @output )  {
                 if ( $line =~ /$if is (.+), line protocol is (.+) / )  {
 			$result{'port'} = $1;
 			$result{'lineprotocol'} = $2;
@@ -184,15 +175,14 @@ sub getIntState  {
 
 }
 
-
+#  Priv 1
 sub getIntDesc  {
         my ( $self, @args ) = @_;
-        $if = &harmonizeInts( $args[0] );
-        $cmd = "sh interface " . $if;
-        if ( !( @result = $self->cmd( $cmd ) ) ) {
-                return 0;
-        }
-        foreach $line ( @result )  {
+        my $if = &harmonizeInts( $args[0] );
+        my $cmd = "sh interface " . $if;
+        my @result = $self->cmd( $cmd );
+
+        foreach my $line ( @result )  {
                 if ( $line =~ /Description: (.+)/ )  {
                         return $1;
                 }  else  { }
@@ -200,15 +190,14 @@ sub getIntDesc  {
 	return 0;
 }
 
-
+#  Priv 1
 sub getEthSpeed  {
         my ( $self, @args ) = @_;
-        $if = &harmonizeInts( $args[0] );
-        $cmd = "sh interface " . $if;
-        if ( !( @result = $self->cmd( $cmd ) ) ) {
-                return 0;
-        }
-        foreach $line ( @result )  {
+        my $if = &harmonizeInts( $args[0] );
+        my $cmd = "sh interface " . $if;
+        my @result = $self->cmd( $cmd );
+
+        foreach my $line ( @result )  {
                 if ( $line =~ /Auto Speed \((.+)\),/ )  {
                         return $1;
                 }  elsif ( $line =~ /, (.+)Mb\/s/ )  {
@@ -218,15 +207,14 @@ sub getEthSpeed  {
 	return 0;
 }
 
-
+#  Priv 1
 sub getEthDuplex  {
         my ( $self, @args ) = @_;
-        $if = &harmonizeInts( $args[0] );
-        $cmd = "sh interface " . $if;
-        if ( !( @result = $self->cmd( $cmd ) ) ) {
-                return 0;
-        }
-        foreach $line ( @result )  {
+        my $if = &harmonizeInts( $args[0] );
+        my $cmd = "sh interface " . $if;
+        my @result = $self->cmd( $cmd );
+
+        foreach my $line ( @result )  {
                 if ( $line =~ /\s+Auto-duplex \((.{4})\),/ )  {
                         return $1;
                 }  elsif ( $line =~ /\s+(.+)-duplex/ )  {
@@ -239,14 +227,14 @@ sub getEthDuplex  {
 	return 0;
 }
 
+#  Priv 1
 sub getIntBandwidth  {
         my ( $self, @args ) = @_;
-        $if = &harmonizeInts( $args[0] );
-        $cmd = "sh interface " . $if;
-        if ( !( @result = $self->cmd( $cmd ) ) ) {
-                return 0;
-        }
-        foreach $line ( @result )  {
+        my $if = &harmonizeInts( $args[0] );
+        my $cmd = "sh interface " . $if;
+        my @result = $self->cmd( $cmd );
+
+        foreach my $line ( @result )  {
                 if ( $line =~ /\s+BW (.+) Kbit/ )  {
                         return $1;
                 }  else  { }
@@ -255,15 +243,14 @@ sub getIntBandwidth  {
 }
 
 
-
+#  Priv 1
 sub getIntInputRate  {
 	my ( $self, @args ) = @_;
-	$if = &harmonizeInts( $args[0] );
-	$cmd = "sh interface " . $if;
-	if ( !( @result = $self->cmd( $cmd ) ) ) { 
-		return 0;
-	}
-	foreach $line ( @result )  {
+	my $if = &harmonizeInts( $args[0] );
+	my $cmd = "sh interface " . $if;
+	my @result = $self->cmd( $cmd );
+
+	foreach my $line ( @result )  {
 		if ( $line =~ /5 minute input rate (.+) bits/ )  {
 			return $1;
 		}  else  { }
@@ -271,14 +258,14 @@ sub getIntInputRate  {
 	
 }
 
+#  Priv 1
 sub getIntInputErrors  {
         my ( $self, @args ) = @_;
-        $if = &harmonizeInts( $args[0] );
-        $cmd = "sh interface " . $if;
-        if ( !( @result = $self->cmd( $cmd ) ) ) {
-                return 0;
-        }
-        foreach $line ( @result )  {
+        my $if = &harmonizeInts( $args[0] );
+        my $cmd = "sh interface " . $if;
+        my @result = $self->cmd( $cmd );
+
+        foreach my $line ( @result )  {
                 if ( $line =~ /(.+) input errors,/ )  {
                         return $1;
                 }  else  { }
@@ -287,15 +274,14 @@ sub getIntInputErrors  {
 
 }
 
-
+#  Priv 1
 sub getIntOutputRate  {
         my ( $self, @args ) = @_;
-        $if = &harmonizeInts( $args[0] );
-        $cmd = "sh interface " . $if;
-        if ( !( @result = $self->cmd( $cmd ) ) ) {
-                return 0;
-        }
-        foreach $line ( @result )  {
+        my $if = &harmonizeInts( $args[0] );
+        my $cmd = "sh interface " . $if;
+        my @result = $self->cmd( $cmd );
+
+        foreach my $line ( @result )  {
                 if ( $line =~ /5 minute output rate (.+) bits/ )  {
                         return $1;
                 }  else  { }
@@ -303,14 +289,14 @@ sub getIntOutputRate  {
 
 }
 
+#  Priv 1
 sub getIntOutputErrors  {
         my ( $self, @args ) = @_;
-        $if = &harmonizeInts( $args[0] );
-        $cmd = "sh interface " . $if;
-        if ( !( @result = $self->cmd( $cmd ) ) ) {
-                return 0;
-        }
-        foreach $line ( @result )  {
+        my $if = &harmonizeInts( $args[0] );
+        my $cmd = "sh interface " . $if;
+        my @result = $self->cmd( $cmd );
+
+        foreach my $line ( @result )  {
                 if ( $line =~ /(.+) output errors,/ )  {
                         return $1;
                 }  else  { }
@@ -318,14 +304,14 @@ sub getIntOutputErrors  {
 	return 0;
 }
 
+#  Priv 1
 sub findVLAN  {
 	my ( $self, @args ) = @_;
-        $if = &harmonizeInts( $args[0] );
-        $cmd = "sh interface " . $if . " status";
-        if ( !( @result = $self->cmd( $cmd ) ) ) {
-                return 0;
-        }
-        foreach $line ( @result )  {
+        my $if = &harmonizeInts( $args[0] );
+        my $cmd = "sh interface " . $if . " status";
+        my @result = $self->cmd( $cmd );
+
+        foreach my $line ( @result )  {
 		if ( $line =~ /^Port/ )  { }
 		elsif ( $line =~ /^-----/ )  { }
 		elsif ( $line =~ /^\s+/ )  { }
@@ -338,25 +324,23 @@ sub findVLAN  {
         return 0;
 }
 
-
+#  Priv 15
 sub getConfig  {
 	my $self = shift;
 	my $cmd = "show running-config";
-	if ( ! ( @result = $self->cmd( $cmd ) ) )  {
-		return 0;
-	}
+	my @result = $self->cmd( $cmd );
+
 	return @result;
 }
 
-
+#  Priv 1
 sub getModel  {
 	my $self = shift;
 	my $cmd = "sh ver";
 	my $plat;
-	if ( !( @result = $self->cmd( $cmd ) ) ) {
-                return 0;
-        }
-        foreach $line ( @result )  {
+	my @result = $self->cmd( $cmd );
+
+        foreach my $line ( @result )  {
                 if ( $line =~ /^IOS \(tm\) (.+) Software/ )  { 
 			return $1;
                 }  elsif  ( $line =~ /cisco (.+) processor/ )  {
@@ -366,29 +350,30 @@ sub getModel  {
         return 0;
 }
 
+#  Priv 1
 sub getPlatform  {
         my ( $self, @args ) = @_;
 	my $platform;
-        $model = $args[0];
+        my $model = $args[0];
 	
 	if ( $model =~ /29.0/ || $model =~ /3750/ )  {
 		return "s";
-	}  elsif  ( $model =~ /RSP/ )  {
+	}  elsif  ( $model =~ /RSP/ || $model =~ /7200/ )  {
 		return "r";
 	} 
 	return 0;
 }
 
-
+#  Priv 1
 sub getIntCAM  {
 	my ( $self, @args ) = @_;
-	$int = harmonizeInts( $args[0] );
-	$cmd = "show mac-address-table interface " . $int;
+	my $int = harmonizeInts( $args[0] );
+	my $cmd = "show mac-address-table interface " . $int;
 	my @ret;
+	my @output = $self->cmd( $cmd );
+	my $model = $self->getModel();
 
-	@output = $self->cmd( $cmd );
-	$model = $self->getModel();
-	foreach $line ( @output )  {
+	foreach my $line ( @output )  {
 		my $mac;
 		if ( $line =~ /(\w{4}\.\w{4}\.\w{4})/ )  {
 			push ( @ret, $1 );
@@ -397,14 +382,15 @@ sub getIntCAM  {
 	return @ret;
 }
 
+#  Priv 1
 sub getIntARP  {
         my ( $self, @args ) = @_;
-        $int = harmonizeInts( $args[0] );
-	$cmd = "show arp";
+        my $int = harmonizeInts( $args[0] );
+	my $cmd = "show arp";
 	my @ret;
-	
-	@output = $self->cmd( $cmd );
-	foreach $line ( @output )  {
+	my @output = $self->cmd( $cmd );
+
+	foreach my $line ( @output )  {
 		chomp $line;
 		if ( $line =~ /$int/ && $line =~ /(\w{4}\.\w{4}\.\w{4})/ )  {
 			push ( @ret, $1 );
@@ -413,16 +399,16 @@ sub getIntARP  {
 	return @ret;
 }
 
-
+#  Priv 1
 sub arpLookup  {
 	my ( $self, @args ) = @_;
-	$cmd = "show arp";
-	
-	@output = $self->cmd( $cmd );
-	foreach $line ( @output )  {
+	my $cmd = "show arp";
+	my @output = $self->cmd( $cmd );
+
+	foreach my $line ( @output )  {
 		chomp $line;
 		if ( $line =~ /$args[0]/ )  {
-			$ip = substr ( $line, 10, 15 );	
+			my $ip = substr ( $line, 10, 15 );	
 			if ( length( $ip ) == 0 )  { }
 			else  {
 				return $ip;
@@ -432,14 +418,14 @@ sub arpLookup  {
 	return 0;
 }
 
+#  Priv 1
 sub getACLs  {
-	$self = shift;
-	$cmd = "show access-lists";
+	my $self = shift;
+	my $cmd = "show access-lists";
 	my @ret;
-	
-	@output = $self->cmd( $cmd );
+	my @output = $self->cmd( $cmd );
 
-	foreach $line ( @output )  {
+	foreach my $line ( @output )  {
 		if ( $line =~ /access list (.+)\n/ )  {
 			push ( @ret, $1 );
 		}
@@ -447,29 +433,44 @@ sub getACLs  {
 	return @ret;
 }
 	
+#  Priv 15
 sub getSNMPComm  {
-	$self = shift;
+	my $self = shift;
 	my @ret;
-	
-	@output = $self->getConfig();
+	my @output = $self->getConfig();
 
-	foreach $line ( @output )  {
+	foreach my $line ( @output )  {
 		if ( $line =~ /snmp-server community (.+) / )  {
 			push ( @ret, $1 );
 		}
 	}
 	return @ret;
 } 
-			
+
+#  Priv 1
+sub privLevel  {
+	my $self = shift;
+	my $cmd = "show privilege";
+	my $ret = 0;
+	my @output = $self->cmd( $cmd );
+
+	foreach my $line ( @output )  {
+		if ( $line =~ /^Current privilege level is (\d{1,2})/ )  {
+			$ret = $1;
+		}
+	}
+	return $ret;
+}
+	
+#  Priv 1			
 sub getVTP  {
-	$self = shift;
-	$cmd = "show vtp status";
+	my $self = shift;
+	my $cmd = "show vtp status";
 	my ( $ver, $mode, $domain );
 	my %ret;
-
-	@output = $self->cmd( $cmd );
+	my @output = $self->cmd( $cmd );
 	
-	foreach $line ( @output )  {
+	foreach my $line ( @output )  {
 		if ( $line =~ /^VTP Version\s+: (.)\n/ )  {
 			$ver = $1;
 		}
@@ -488,27 +489,27 @@ sub getVTP  {
 	return %ret;
 }
 
+#  Priv 1
 sub getIntACL  {
 	my ( $self, @args ) = @_;
 	my $inacl = 0;
 	my $outacl = 0;
-        $cmd = "show ip int " . $args[0];
-	@outacl =  ("Outgoing access list is ", "Outbound access list is ");
-	@inacl = ("Inbound  access list is ", "Inbound access list is ");
+        my $cmd = "show ip int " . $args[0];
+	my @outacl =  ("Outgoing access list is ", "Outbound access list is ");
+	my @inacl = ("Inbound  access list is ", "Inbound access list is ");
         my %ret;
-
-	@output = $self->cmd( $cmd );
+	my @output = $self->cmd( $cmd );
 	
-	foreach $line ( @output )  {
+	foreach my $line ( @output )  {
 		ACL:
 		{
-			foreach $acl ( @outacl )  {
+			foreach my $acl ( @outacl )  {
 				if ( $line =~ /$acl(.+)/ )  {
 					$outacl = $1;
 					last ACL;
 				}	
 			}
-			foreach $acl ( @inacl )  {
+			foreach my $acl ( @inacl )  {
 				if ( $line =~ /$acl(.+)/ )  {
 					$inacl = $1;
 					last ACL;
@@ -531,35 +532,64 @@ sub getIntACL  {
 	return %ret;
 }
 
+#  Priv 1
 sub getIPRoute  {
 	my ( $self, @args ) = @_;
-	my %ret = ( 	protocol => 0,
+	my %ret = ( 	route => 0,
+			protocol => 0,
 		 	nexthop => 0);
 	my $cmd = "show ip route " . $args[0];
-	if ( !( @result = $self->cmd( $cmd ) ) )  {
-		return %ret;
-	}
-	foreach $line ( @result )  {
+	my @result = $self->cmd( $cmd );
+	foreach my $line ( @result )  {
+		if ( $line =~ /Routing entry for (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}\/\d{1,2})/ )  {
+			$ret{'route'} = $1;
+		}
 		if ( $line =~ /Known via \"(.+)\"/ )  {
 			$ret{ 'protocol' } = $1;
 		}
 		if ( $line =~ /directly connected, via (.+)\W/ )  {
 			$ret{ 'nexthop' } = $1;
 		}
-		if ( $line =~ /\* (\w{1,3}\.\w{1,3}\.\w{1,3}\.\w{1,3})/ )  {
+		if ( $line =~ /\* (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/ )  {
 			$ret{ 'nexthop' } = $1;
 		}
 	}
 	return %ret;
 }
 
+# Priv 15
+sub getNTP  {
+	my $self = shift;
+	my %ret;
+	my ( $server, $source, $mode );
 
+	my @result = $self->getConfig();
+	foreach my $line ( @result )  {
+		if ( $line =~ /^ntp server (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}) source (\w+) (\w+)/ )  {    
+			$server = $1;
+			$source = harmonizeInts( $2 );
+			$mode = $3;
+                }
+		elsif ( $line =~ /^ntp server (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}) prefer/ )  {
+			$server = $1;
+			$mode = "prefer";
+		}
+		elsif ( $line =~ /^ntp source (.+)$/ )  {
+			$source =  harmonizeInts( $1 );
+		}
+	}
+	%ret = (	server => $server,
+			source => $source,
+			mode => $mode );
+	return %ret;
+}
+#  Priv 15
 sub disableInt  {
 #  Fix the return codes.
 	my ( $self, @args ) = @_;
-	my $result;
-	$if = &harmonizeInts( $args[0] );
-	$cmd = "shutdown";
+	my  $result;
+	my $if = &harmonizeInts( $args[0] );
+	my $cmd = "shutdown";
 	eval  {
 		$self->cmd( "configure terminal" );
 		$self->cmd( "interface $if" );
@@ -572,9 +602,10 @@ sub disableInt  {
 	return 1;
 }
 
+#  Priv 15
 sub saveConfig  {
 	my $self = shift;
-	$cmd = "write memory";
+	my $cmd = "write memory";
 	if ( !$self->cmd( $cmd ) )  {
 		print "Couldn't do it";
 		<STDIN>;
@@ -583,7 +614,6 @@ sub saveConfig  {
 	return 1;
 }
 
-
 sub harmonizeInts  {
 	my $input = shift;
 	my @FastEthernet = qw(FastEthernet FastEth Fast FE Fa F);
@@ -593,10 +623,11 @@ sub harmonizeInts  {
 	my @PortChannel = qw(PortChannel Port-Channel Po);
 	my @POS = qw(POS P);
 	my @VLAN = qw(VLAN VL V);
+	my @LOOPBACK = qw(Loopback Loop Lo);
 	IFS:
 	{
 		#  Go through the array @FastEthernet
-        	foreach $fe ( @FastEthernet )
+        	foreach my $fe ( @FastEthernet )
         	{
                		#  If the user's input matches
                 	if ( $input =~ /^$fe\d/i )
@@ -610,7 +641,7 @@ sub harmonizeInts  {
         		}
 		}
 		#  Go through the array @GigEthernet
-                foreach $ge ( @GigEthernet )
+                foreach my $ge ( @GigEthernet )
                 {
                         #  If the user's input matches
                         if ( $input =~ /^$ge\d/i )
@@ -624,7 +655,7 @@ sub harmonizeInts  {
                         }
                 }
 		#  Go through the array @Ethernet
-                foreach $e ( @Ethernet )
+                foreach my $e ( @Ethernet )
                 {
                         #  If the user's input matches
                         if ( $input =~ /^$e\d/i )
@@ -638,7 +669,7 @@ sub harmonizeInts  {
                         }
                 }
 		#  Go through the array @Serial
-                foreach $s ( @Serial )
+                foreach my $s ( @Serial )
                 {
                         #  If the user's input matches
                         if ( $input =~ /^$s\d/i )
@@ -652,7 +683,7 @@ sub harmonizeInts  {
                         }
                 }
 		#  Go through the array @PortChannel
-                foreach $po ( @PortChannel )
+                foreach my $po ( @PortChannel )
                 {
                         #  If the user's input matches
                         if ( $input =~ /^$po\d/i )
@@ -666,7 +697,7 @@ sub harmonizeInts  {
                         }
                 }
 		#  Go through the array @POS
-                foreach $pos ( @POS )
+                foreach my $pos ( @POS )
                 {
                         #  If the user's input matches
                         if ( $input =~ /^$pos\d/i )
@@ -680,7 +711,7 @@ sub harmonizeInts  {
                         }
                 }
 		#  Go through the array @VLAN
-		foreach $vlan ( @VLAN )
+		foreach my $vlan ( @VLAN )
                 {
                         #  If the user's input matches
                         if ( $input =~ /^$vlan\d/i )
@@ -693,6 +724,20 @@ sub harmonizeInts  {
                                 last IFS;
                         }
                 }
+		# Go through the array @LOOPBACK
+		foreach my $lb ( @LOOPBACK )
+                {
+                        #  If the user's input matches
+                        if ( $input =~ /^$lb\d/i )
+                        {
+                                #  Take the number part out
+                                $input =~ /^$lb(.+)\b/i;
+                                #  Reset $val to the long name + number
+                                $input = "Loopback" . $1;
+                                #  Leave the block because we found it
+                                last IFS;
+                        }
+                }
 		#  Since we didn't find it, set $input to 0
 		return 0;
 	}  #  IFS
@@ -701,23 +746,25 @@ sub harmonizeInts  {
 }
 
 1;
+
+
 =head1 NAME
 
 Net::Telnet::Cisco::IOS -- Manage Cisco IOS Devices
 
 =head1 DESCRIPTION
 
-Net::Telnet::Cisco::IOS (NTCI) is an extension of Joshua Kereos's Net::Telnet::Cisco module and provides an easy way to manage and monitor Cisco IOS devices.  I'll mention this a lot, but make sure you read up on Net::Telnet::Cisco for a lot of information.  I'm a network guy, not a developer, so I'm not familiar with the Perl community and how everything is done.  With that in mind, I've resorted to copying a lot of stuff and changing keywords.  This POD, for example, is a direct ripoff of Josh Kereos's POD for Net::Telnet::Cisco.  Forgive me, all.  :)
+Net::Telnet::Cisco::IOS (NTCI) is an extension of Joshua Kereos's Net::Telnet::Cisco module and provides an easy way to manage and monitor Cisco IOS devices.  I'll mention this a lot, but make sure you read up on Net::Telnet::Cisco for a lot of information.
 
 =head1 WHEN TO USE NTCI
 
-NTCI can do a lot, but it's not the best way to do all of it.  I'd suggest you take a look at some SNMP solutions.  It's up to you to figure out when and where you want to use it, but don't say I didn't warn you.
+NTCI can do a lot, but it's not the best way to do all of it.  I'd suggest you take a look at some SNMP solutions.  It's up to you to figure out when and where you want to use it, but don't say I didn't warn you.  :)
 
 =head1 METHODS
 
 There are way too many methods to list here, so head over to http://ntci.sourceforge.net for a full list with documentation.
 
-=head1 SHORT EXAMPLE
+=head1 SYNOPSIS
 
 	use Net::Telnet::Cisco:IOS;
 
